#!/usr/bin/env Rscript

# Load libraries

library(shiny)
library(RColorBrewer)
library(ggplot2)

# CLI arguments

args <- commandArgs(trailingOnly = T)
in_kallisto_df <- args[1]
exp_factor <- args[2]

# Load data

expression_data <- read.csv(file = in_kallisto_df)
available_genes <- unique(expression_data$target_id)

expression_data$condition = expression_data[,exp_factor]

# Design app

ui <- fluidPage(
  
  sidebarLayout(
    sidebarPanel(
      selectizeInput(
        multiple = TRUE, "target", label = "Select Gene by target id",
        selected = sample(available_genes, size = 3),
        choices = NULL,  # Start with no choices
        options = list(
          server = TRUE,  # Enable server-side processing
          delimiter = " ",
          create = I("function(input, callback){return {value: input, text: input};}")
        )
      )
    ),
    mainPanel(
      plotOutput("exPlot")
    )
  )
)

# Server logic
server <- function(input, output, session) {
  
  # Dynamically load the available genes
  observe({
    updateSelectizeInput(session, "target", choices = available_genes, server = TRUE)
  })
  
  output$exPlot <- renderPlot({
    plot_set <- subset(expression_data, target_id %in% input$target)
    
    # Facetted plot by gene
    ggplot(plot_set, aes(x = condition, y = tpm)) +
      stat_summary(fun = "mean", geom = "bar") +
      geom_point(size = 0.5) +
      facet_wrap(~target_id, scales = "free") +
      theme_minimal() +
      theme(aspect.ratio = 1)
  })
}

# Launch app

shinyApp(ui, server)
